import React, { useState, useContext } from 'react';
import { Modal, Button, Form } from 'react-bootstrap';
import { consentContext } from 'compendium/providers/ConsentProvider';

const PrivacyModal: React.FC = () => {
    const { consent, setConsent } = useContext(consentContext);
    const [show, setShow] = useState(consent === null);
    const handleClose = () => {
        setShow(false)
        window.location.reload(); // reload the page to apply the new consent
    };

    const [checked, setChecked] = useState(true);

    const saveConsent = (consent) => {
        // save consent to local storage, if it's been over 30 days, ask again
        const consentExpiry = new Date();
        consentExpiry.setDate(consentExpiry.getDate() + 30);
        localStorage.setItem('matomo_consent', JSON.stringify({ consent, expiry: consentExpiry }));
        setConsent(consent);
    }

    return (
        <Modal show={show} centered>
            <Modal.Header closeButton>
                <Modal.Title>Privacy on this site</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <p>
                    On our site we use Matomo to collect and process data about your visit to better understand how it is used.
                    For more information, see our <a href="https://geant.org/Privacy-Notice/">Privacy Policy</a>.
                    <br />Below, you can choose to accept or decline to have this data collected.
                </p>
                <Form>
                    <Form.Group className="mb-3">
                        <Form.Check type="checkbox" label="Analytics" checked={checked} onChange={() => setChecked(!checked)} />
                        <Form.Text className="text-muted">
                            We collect information about your visit on the compendium site &mdash; this helps us understand how the site is used, and how we can improve it.
                        </Form.Text>
                    </Form.Group>
                </Form>
            </Modal.Body>
            <Modal.Footer>
                <Button variant="secondary" onClick={() => {
                    saveConsent(false);
                    handleClose();
                }}>
                    Decline all
                </Button>
                <Button variant="primary" onClick={() => {
                    saveConsent(checked);
                    handleClose();
                }}>
                    Save consent for 30 days
                </Button>
            </Modal.Footer>
        </Modal>
    );
}

export default PrivacyModal;