import { useContext } from 'react';

import { RemoteCampuses } from "compendium/Schema";
import { createDataLookupList, getTableData } from "compendium/helpers/dataconversion";
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from 'compendium/helpers/useData';
import MulticolumnNrenYearTable from 'compendium/components/MulticolumnNrenYearTable';
import titles from "compendium/titles";

function RemoteCampusesPage() {
    const field = 'remote_campus_connectivity';
    const validityCheck = (data: RemoteCampuses) => !!data[field];
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<RemoteCampuses>('/api/remote-campuses', setFilterSelection, validityCheck);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );
    const organisationDataset = createDataLookupList(selectedData);

    const dataByYear = getTableData(organisationDataset, (obj, campuses) => {
        for (const campus of campuses) {
            if (!campus.remote_campus_connectivity) {
                continue;
            }

            const countries = campus.connections.map(connection => connection.country).join(', ');
            obj['countries'] = countries;
            obj['local_r_and_e_connection'] = campus.connections.map(connection => connection.local_r_and_e_connection ? 'Yes' : 'No').join(', ');

        }
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    const columns = {
        countries: 'Countries with Remote Campuses',
        local_r_and_e_connection: 'Local R&E Connection'
    }

    return (
        <DataPage title={titles["remote-campuses"]}
            description='NRENs are asked whether they have remote campuses in other countries, and if so, to list the countries where they have remote campuses and whether they are connected to the local R&E network.'
            category={Sections.ConnectedUsers} filter={filterNode}
            data={selectedData} filename='nren_remote_campuses'>
            <ChartContainer>
                <MulticolumnNrenYearTable data={dataByYear} columns={columns} dottedBorder />
            </ChartContainer>
        </DataPage>
    );
}
export default RemoteCampusesPage;
