import React, { useContext } from "react";
import { MonitoringTools } from "compendium/Schema";
import { createNrenTableLookup, addTooltip } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function MonitoringToolsPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<MonitoringTools>('/api/monitoring-tools', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'tool_descriptions');

    const processTooltip = (column: string, monitoringtools: MonitoringTools) => {
        if (column !== 'netflow_analysis') return;

        if (!monitoringtools.netflow_processing_description) {
            return;
        }
        return monitoringtools.netflow_processing_description;
    }

    const withTooltip = addTooltip(dataLookup, processTooltip);

    const columns = [
        "Looking Glass",
        "Network or Services Status Dashboard",
        "Historical traffic volume information",
        "Netflow analysis tool",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "looking_glass"],
        [columns[1], "status_dashboard"],
        [columns[2], "historical_traffic_volumes"],
        [columns[3], "netflow_analysis"],
    ]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles['monitoring-tools']}
            description="The table below shows which tools the NREN offers to client institutions to allow them to monitor the network and troubleshoot any issues which arise. 
            Four common tools are named, however NRENs also have the opportunity to add their own tools to the table."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="monitoring_tools_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} columnLookup={columnValueMap} dataLookup={withTooltip} />
            </ChartContainer>
        </DataPage>
    );
}
export default MonitoringToolsPage;
