import React, { useContext } from "react";
import { ChargingStructure } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function ChargingStructurePage(): React.ReactElement {

    const validityCheck = (data: ChargingStructure) => data.fee_type != null;

    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<ChargingStructure>('/api/charging', setFilterSelection, validityCheck);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'fee_type');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const columns = [
        "Flat fee based on bandwidth",
        "Usage based fee",
        "Combination flat fee & usage basedfee",
        "No Direct Charge",
        "Other",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "flat_fee"],
        [columns[1], "usage_based_fee"],
        [columns[2], "combination"],
        [columns[3], "no_charge"],
        [columns[4], "other"],
    ]);

    return (
        <DataPage title={titles.charging}
            description="The charging structure is the way in which NRENs charge their customers for the services they provide.
         The charging structure can be based on a flat fee, usage based fee, a combination of both, or no direct charge. 
         By selecting multiple years and NRENs, the table can be used to compare the charging structure of NRENs."
            category={Sections.Organisation} filter={filterNode}
            data={selectedData} filename="charging_mechanism_of_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} dataLookup={dataLookup} columnLookup={columnValueMap} />
            </ChartContainer>
        </DataPage>
    );
}
export default ChargingStructurePage;
