import { useContext } from 'react';
import { Organisation } from "compendium/Schema";
import { createDataLookup, getTableData } from "compendium/helpers/dataconversion";
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from 'compendium/helpers/useData';
import NrenYearTable from 'compendium/components/NrenYearTable';

function ParentOrganisationPage() {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data: organisationData, years, nrens } = useData<Organisation>('/api/parent-organizations', setFilterSelection);

    const selectedData = organisationData.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );
    const organisationDataset = createDataLookup(selectedData);

    const dataByYear = getTableData(organisationDataset, (obj, org) => {
        const value = org.name;
        obj[value] = value;
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        max1year
    />

    return (
        <DataPage title="NREN Parent Organisations"
            description='Some NRENs are part of larger organisations, including Ministries or universities. These are shown in the table below. Only NRENs who are managed in this way are available to select.'
            category={Sections.Organisation} filter={filterNode}
            data={selectedData} filename="nren_parent_organisations">
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Parent Organisation" dottedBorder noDots />
            </ChartContainer>
        </DataPage>

    );
}
export default ParentOrganisationPage;
