import { useContext } from 'react';

import { Organisation } from "compendium/Schema";
import { createDataLookupList, getTableData } from "compendium/helpers/dataconversion";
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from 'compendium/helpers/useData';
import NrenYearTable from 'compendium/components/NrenYearTable';
import titles from "compendium/titles";

function SubOrganisationPage() {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<Organisation>('/api/sub-organizations', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );
    const organisationDataset = createDataLookupList(selectedData);

    const dataByYear = getTableData(organisationDataset, (obj, orgs) => {
        for (const org of orgs.sort((a, b) => a.name.localeCompare(b.name))) {
            const value = `${org.name} (${org.role})`;
            obj[value] = value;
        }
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title={titles.suborganisations}
            description='NRENs are asked whether they have any sub-organisations, and to give the name and role of these organisations. These organisations can include HPC centres or IDC federations, amongst many others.'
            category={Sections.Organisation} filter={filterNode}
            data={selectedData} filename='nren_suborganisations'>
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Suborganisation and Role" dottedBorder />
            </ChartContainer>
        </DataPage>
    );
}
export default SubOrganisationPage;
