import React, { createContext, useState } from 'react';

interface Props {
    children: React.ReactNode;
}

const consentContext = createContext<{
    consent: boolean | null;
    setConsent: (consent: boolean) => void;
}>({
    consent: null,
    setConsent: () => { }
});

const ConsentProvider: React.FC<Props> = ({ children }) => {

    const getConsent = () => {
        const consent = localStorage.getItem('matomo_consent');
        if (consent) {
            const parsed = JSON.parse(consent);
            if (new Date(parsed.expiry) > new Date()) {
                return parsed.consent;
            }
        }
        return null;
    }
    const [consent, setConsent] = useState(getConsent());
    return (
        <consentContext.Provider value={{ setConsent: (consent) => setConsent(consent), consent }}>
            {children}
        </consentContext.Provider>
    );
};

export { consentContext };
export default ConsentProvider;