"""add presentation models

Revision ID: 8ff7260ad48f
Revises: e17f9e6c90ab
Create Date: 2023-09-14 15:09:36.301058

"""

# flake8: noqa

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = '8ff7260ad48f'
down_revision = 'e17f9e6c90ab'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    sa.Enum('yes', 'no', 'planned', name='yesnoplanned').create(op.get_bind())
    sa.Enum('span_ports', 'taps', 'both', name='monitoringmethod').create(op.get_bind())
    sa.Enum('higher_than_r_e_charges', 'same_as_r_e_charges', 'no_charges_if_r_e_requested', 'lower_than_r_e_charges', name='commarcialcharginglevel').create(op.get_bind())
    sa.Enum('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage').create(op.get_bind())
    sa.Enum('nren_local_loops', 'regional_nren_backbone', 'commercial_provider_backbone', 'man', 'other', name='carrymechanism').create(op.get_bind())
    sa.Enum('yes_incl_other', 'yes_national_nren', 'sometimes', 'no_policy', 'no_financial', 'no_other', 'unsure', name='connectivitycoverage').create(op.get_bind())
    sa.Enum('network_services', 'isp_support', 'security', 'identity', 'collaboration', 'multimedia', 'storage_and_hosting', 'professional_services', name='servicecategory').create(op.get_bind())
    sa.Enum('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory').create(op.get_bind())
    op.create_table('alien_wave',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('alien_wave_third_pary', postgresql.ENUM('yes', 'no', 'planned', name='yesnoplanned', create_type=False), nullable=True),
    sa.Column('nr_of_alien_wave_third_party_services', sa.Integer(), nullable=True),
    sa.Column('alien_wave_internal', sa.Boolean(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_alien_wave_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_alien_wave'))
    )
    op.create_table('capacity',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('largest_link_capacity', sa.Numeric(), nullable=True),
    sa.Column('typical_backbone_capacity', sa.Numeric(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_capacity_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_capacity'))
    )
    op.create_table('central_procurement',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('central_procurement', sa.Boolean(), nullable=False),
    sa.Column('amount', sa.Numeric(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_central_procurement_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_central_procurement'))
    )
    op.create_table('certificate_providers',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('provider_names', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_certificate_providers_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_certificate_providers'))
    )
    op.create_table('commercial_charging_level',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('collaboration', postgresql.ENUM('higher_than_r_e_charges', 'same_as_r_e_charges', 'no_charges_if_r_e_requested', 'lower_than_r_e_charges', name='commarcialcharginglevel', create_type=False), nullable=True),
    sa.Column('service_supplier', postgresql.ENUM('higher_than_r_e_charges', 'same_as_r_e_charges', 'no_charges_if_r_e_requested', 'lower_than_r_e_charges', name='commarcialcharginglevel', create_type=False), nullable=True),
    sa.Column('direct_peering', postgresql.ENUM('higher_than_r_e_charges', 'same_as_r_e_charges', 'no_charges_if_r_e_requested', 'lower_than_r_e_charges', name='commarcialcharginglevel', create_type=False), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_commercial_charging_level_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_commercial_charging_level'))
    )
    op.create_table('commercial_connectivity',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('commercial_r_and_e', postgresql.ENUM('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage', create_type=False), nullable=True),
    sa.Column('commercial_general', postgresql.ENUM('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage', create_type=False), nullable=True),
    sa.Column('commercial_collaboration', postgresql.ENUM('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage', create_type=False), nullable=True),
    sa.Column('commercial_service_provider', postgresql.ENUM('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage', create_type=False), nullable=True),
    sa.Column('university_spin_off', postgresql.ENUM('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage', create_type=False), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_commercial_connectivity_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_commercial_connectivity'))
    )
    op.create_table('connected_proportion',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('user_category', postgresql.ENUM('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory', create_type=False), nullable=False),
    sa.Column('coverage', postgresql.ENUM('yes_incl_other', 'yes_national_nren', 'sometimes', 'no_policy', 'no_financial', 'no_other', 'unsure', name='connectivitycoverage', create_type=False), nullable=True),
    sa.Column('number_connected', sa.Integer(), nullable=True),
    sa.Column('market_share', sa.Numeric(), nullable=True),
    sa.Column('users_served', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_connected_proportion_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', 'user_category', name=op.f('pk_connected_proportion'))
    )
    op.create_table('connection_carrier',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('user_category', postgresql.ENUM('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory', create_type=False), nullable=False),
    sa.Column('carry_mechanism', postgresql.ENUM('nren_local_loops', 'regional_nren_backbone', 'commercial_provider_backbone', 'man', 'other', name='carrymechanism', create_type=False), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_connection_carrier_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', 'user_category', name=op.f('pk_connection_carrier'))
    )
    op.create_table('connectivity_growth',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('user_category', postgresql.ENUM('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory', create_type=False), nullable=False),
    sa.Column('growth', sa.Numeric(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_connectivity_growth_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', 'user_category', name=op.f('pk_connectivity_growth'))
    )
    op.create_table('connectivity_level',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('user_category', postgresql.ENUM('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory', create_type=False), nullable=False),
    sa.Column('typical_speed', sa.Integer(), nullable=True),
    sa.Column('highest_speed', sa.Integer(), nullable=True),
    sa.Column('highest_speed_proportion', sa.Numeric(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_connectivity_level_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', 'user_category', name=op.f('pk_connectivity_level'))
    )
    op.create_table('connectivity_load',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('user_category', postgresql.ENUM('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory', create_type=False), nullable=False),
    sa.Column('average_load_from_institutions', sa.Integer(), nullable=True),
    sa.Column('average_load_to_institutions', sa.Integer(), nullable=True),
    sa.Column('peak_load_from_institutions', sa.Integer(), nullable=True),
    sa.Column('peak_load_to_institutions', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_connectivity_load_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', 'user_category', name=op.f('pk_connectivity_load'))
    )
    op.create_table('crisis_excercises',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('exercise_descriptions', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_crisis_excercises_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_crisis_excercises'))
    )
    op.create_table('dark_fibre_installed',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('installed', sa.Boolean(), nullable=False),
    sa.Column('fibre_length_in_country', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_dark_fibre_installed_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_dark_fibre_installed'))
    )
    op.create_table('dark_fibre_lease',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('iru_or_lease', sa.Boolean(), nullable=False),
    sa.Column('fibre_length_in_country', sa.Integer(), nullable=True),
    sa.Column('fibre_length_outside_country', sa.Integer(), nullable=True),
    sa.Column('iru_duration', sa.Numeric(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_dark_fibre_lease_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_dark_fibre_lease'))
    )
    op.create_table('eosc_listings',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('service_names', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_eosc_listings_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_eosc_listings'))
    )
    op.create_table('external_connections',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('connections', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_external_connections_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_external_connections'))
    )
    op.create_table('fibre_light',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('light_description', sa.String(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_fibre_light_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_fibre_light'))
    )
    op.create_table('monitoring_tools',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('tool_descriptions', sa.JSON(), nullable=False),
    sa.Column('netflow_processing_description', sa.String(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_monitoring_tools_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_monitoring_tools'))
    )
    op.create_table('network_automation',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('network_automation', postgresql.ENUM('yes', 'no', 'planned', name='yesnoplanned', create_type=False), nullable=False),
    sa.Column('network_automation_specifics', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_network_automation_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_network_automation'))
    )
    op.create_table('network_function_virtualisation',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('nfv', postgresql.ENUM('yes', 'no', 'planned', name='yesnoplanned', create_type=False), nullable=False),
    sa.Column('nfv_specifics', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_network_function_virtualisation_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_network_function_virtualisation'))
    )
    op.create_table('network_map_urls',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('urls', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_network_map_urls_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_network_map_urls'))
    )
    op.create_table('non_r_and_e_peers',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('nr_of_non_r_and_e_peers', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_non_r_and_e_peers_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_non_r_and_e_peers'))
    )
    op.create_table('ops_automation',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('ops_automation', postgresql.ENUM('yes', 'no', 'planned', name='yesnoplanned', create_type=False), nullable=False),
    sa.Column('ops_automation_specifics', sa.String(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_ops_automation_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_ops_automation'))
    )
    op.create_table('passive_monitoring',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('monitoring', sa.Boolean(), nullable=False),
    sa.Column('method', postgresql.ENUM('span_ports', 'taps', 'both', name='monitoringmethod', create_type=False), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_passive_monitoring_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_passive_monitoring'))
    )
    op.create_table('pert_team',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('pert_team', postgresql.ENUM('yes', 'no', 'planned', name='yesnoplanned', create_type=False), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_pert_team_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_pert_team'))
    )
    op.create_table('remote_campuses',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('remote_campus_connectivity', sa.Boolean(), nullable=False),
    sa.Column('connections', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_remote_campuses_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_remote_campuses'))
    )
    op.create_table('security_controls',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('security_control_descriptions', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_security_controls_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_security_controls'))
    )
    op.create_table('service_management',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('service_management_framework', sa.Boolean(), nullable=True),
    sa.Column('service_level_targets', sa.Boolean(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_service_management_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_service_management'))
    )
    op.create_table('service_user_types',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('user_category', postgresql.ENUM('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory', create_type=False), nullable=False),
    sa.Column('service_category', postgresql.ENUM('network_services', 'isp_support', 'security', 'identity', 'collaboration', 'multimedia', 'storage_and_hosting', 'professional_services', name='servicecategory', create_type=False), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_service_user_types_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', 'user_category', name=op.f('pk_service_user_types'))
    )
    op.create_table('siem_vendors',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('vendor_names', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_siem_vendors_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_siem_vendors'))
    )
    op.create_table('standards',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('audits', sa.Boolean(), nullable=True),
    sa.Column('audit_specifics', sa.String(), nullable=False),
    sa.Column('business_continuity_plans', sa.Boolean(), nullable=True),
    sa.Column('business_continuity_plans_specifics', sa.String(), nullable=False),
    sa.Column('crisis_management_procedure', sa.Boolean(), nullable=True),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_standards_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_standards'))
    )
    op.create_table('traffic_ratio',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('r_and_e_percentage', sa.Integer(), nullable=False),
    sa.Column('commodity_percentage', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_traffic_ratio_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_traffic_ratio'))
    )
    op.create_table('traffic_statistics',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('traffic_statistics', sa.Boolean(), nullable=False),
    sa.Column('urls', sa.JSON(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_traffic_statistics_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_traffic_statistics'))
    )
    op.create_table('weather_map',
    sa.Column('nren_id', sa.Integer(), nullable=False),
    sa.Column('year', sa.Integer(), nullable=False),
    sa.Column('weather_map', sa.Boolean(), nullable=False),
    sa.Column('url', sa.String(), nullable=False),
    sa.ForeignKeyConstraint(['nren_id'], ['nren.id'], name=op.f('fk_weather_map_nren_id_nren')),
    sa.PrimaryKeyConstraint('nren_id', 'year', name=op.f('pk_weather_map'))
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('weather_map')
    op.drop_table('traffic_statistics')
    op.drop_table('traffic_ratio')
    op.drop_table('standards')
    op.drop_table('siem_vendors')
    op.drop_table('service_user_types')
    op.drop_table('service_management')
    op.drop_table('security_controls')
    op.drop_table('remote_campuses')
    op.drop_table('pert_team')
    op.drop_table('passive_monitoring')
    op.drop_table('ops_automation')
    op.drop_table('non_r_and_e_peers')
    op.drop_table('network_map_urls')
    op.drop_table('network_function_virtualisation')
    op.drop_table('network_automation')
    op.drop_table('monitoring_tools')
    op.drop_table('fibre_light')
    op.drop_table('external_connections')
    op.drop_table('eosc_listings')
    op.drop_table('dark_fibre_lease')
    op.drop_table('dark_fibre_installed')
    op.drop_table('crisis_excercises')
    op.drop_table('connectivity_load')
    op.drop_table('connectivity_level')
    op.drop_table('connectivity_growth')
    op.drop_table('connection_carrier')
    op.drop_table('connected_proportion')
    op.drop_table('commercial_connectivity')
    op.drop_table('commercial_charging_level')
    op.drop_table('certificate_providers')
    op.drop_table('central_procurement')
    op.drop_table('capacity')
    op.drop_table('alien_wave')
    sa.Enum('universities', 'further_education', 'secondary_schools', 'primary_schools', 'institutes', 'cultural', 'hospitals', 'government', 'iros', 'for_profit_orgs', name='usercategory').drop(op.get_bind())
    sa.Enum('network_services', 'isp_support', 'security', 'identity', 'collaboration', 'multimedia', 'storage_and_hosting', 'professional_services', name='servicecategory').drop(op.get_bind())
    sa.Enum('yes_incl_other', 'yes_national_nren', 'sometimes', 'no_policy', 'no_financial', 'no_other', 'unsure', name='connectivitycoverage').drop(op.get_bind())
    sa.Enum('nren_local_loops', 'regional_nren_backbone', 'commercial_provider_backbone', 'man', 'other', name='carrymechanism').drop(op.get_bind())
    sa.Enum('yes_incl_other', 'yes_national_nren', 'yes_if_sponsored', 'no_but_direct_peering', 'no_policy', 'no_financial', 'no_other', name='commercialconnectivitycoverage').drop(op.get_bind())
    sa.Enum('higher_than_r_e_charges', 'same_as_r_e_charges', 'no_charges_if_r_e_requested', 'lower_than_r_e_charges', name='commarcialcharginglevel').drop(op.get_bind())
    sa.Enum('span_ports', 'taps', 'both', name='monitoringmethod').drop(op.get_bind())
    sa.Enum('yes', 'no', 'planned', name='yesnoplanned').drop(op.get_bind())
    # ### end Alembic commands ###
