import re
from validators.url import url as url_parse
from typing import List

from sqlalchemy import select

from compendium_v2.db import db, presentation_models

URL_PATTERN = re.compile(
    (r'\b(https?://[^\s<>";,(){}\[\]!\\]+'
     r'|www\.[^\s<>";,(){}\[\]!\\]+'
     r'|[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4})'
     r'\b(?=\s|\b|[,!?.;:\\])')
)


def map_nren(nren):
    nren_dict = {}
    nren_dict['ASNET'] = 'ASNET-AM'
    nren_dict['KIFU (NIIF)'] = 'KIFU'
    nren_dict['KIFÜ'] = 'KIFU'
    nren_dict['NIIF/HUNGARNET'] = 'KIFU'
    nren_dict['SURFNET'] = 'SURF'
    nren_dict['UOM/RICERKANET'] = 'UNIVERSITY OF MALTA'
    nren_dict['UOM'] = 'UNIVERSITY OF MALTA'
    nren_dict['UNINETT'] = 'SIKT'
    nren_dict['LANET'] = 'LAT'
    nren_dict['ANA'] = 'RASH'
    nren_dict['ANAS'] = 'AZSCIENCENET'
    nren_dict['GRNET S.A.'] = 'GRNET'
    nren_dict['FUNET'] = 'CSC'
    nren_dict['PIONIER'] = 'PSNC'
    nren_dict['PIONEER'] = 'PSNC'
    return nren_dict.get((nren or '').upper(), nren)


def get_uppercase_nren_dict():
    """
    :return: a dictionary of all known NRENs db entities keyed on the uppercased name
    """
    current_nrens = db.session.scalars(select(presentation_models.NREN))
    nren_dict = {nren.name.upper(): nren for nren in current_nrens}
    # add aliases that are used in the source data:
    nren_dict['ASNET'] = nren_dict['ASNET-AM']
    nren_dict['KIFU (NIIF)'] = nren_dict['KIFU']
    nren_dict['KIFÜ'] = nren_dict['KIFU']
    nren_dict['NIIF/HUNGARNET'] = nren_dict['KIFU']
    nren_dict['SURFNET'] = nren_dict['SURF']
    nren_dict['UOM/RICERKANET'] = nren_dict['UNIVERSITY OF MALTA']
    nren_dict['UOM'] = nren_dict['UNIVERSITY OF MALTA']
    nren_dict['UNINETT'] = nren_dict['SIKT']
    nren_dict['LANET'] = nren_dict['LAT']
    nren_dict['ANA'] = nren_dict['RASH']
    nren_dict['ANAS'] = nren_dict['AZSCIENCENET']
    nren_dict['GRNET S.A.'] = nren_dict['GRNET']
    nren_dict['FUNET'] = nren_dict['CSC']
    nren_dict['PIONIER'] = nren_dict['PSNC']
    nren_dict['PIONEER'] = nren_dict['PSNC']
    return nren_dict


def extract_urls(text: str) -> List[str]:
    return re.findall(URL_PATTERN, text)


def valid_url(url: str) -> bool:
    try:
        parsed = url_parse(url)
        valid = bool(parsed)
        if not valid:
            # if it's valid with the scheme added, then we're fine
            parsed = url_parse('http://' + url)
            valid = bool(parsed)
    except Exception:
        valid = False
    return valid


def merge_string(old, new):
    if not old:
        return new
    if not new:
        return old
    return f'{old} / {new}'
