"""
This module contains the JSON schemas for the API responses.

The schemas are used to validate the responses of the API endpoints.
"""


NREN_YEAR_DATAPOINT = {
    'nren': {'type': 'string'},
    'nren_country': {'type': 'string'},
    'year': {'type': 'integer'}
}

NREN_YEAR_DATAPOINT_REQUIRED = ['nren', 'nren_country', 'year']


ALIEN_WAVE_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'alien_wave': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'alien_wave_third_party': {'type': ['string', 'null']},
                'nr_of_alien_wave_third_party_services': {'type': ['integer', 'null']},
                'alien_wave_internal': {'type': ['boolean', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/alien_wave'}
}

BUDGET_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'budget': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'budget': {'type': 'number'},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'budget'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/budget'}
}

CAPACITY_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'capacity': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'largest_link_capacity': {'type': ['number', 'null']},
                'typical_backbone_capacity': {'type': ['number', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/capacity'}
}

CENTRAL_PROCUREMENT_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'central_procurement': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'central_procurement': {'type': 'boolean'},
                'amount': {'type': ['number', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'central_procurement', 'amount'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/central_procurement'}
}

CERTIFICATE_PROVIDER_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'certificate_provider': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'provider_names': {'type': 'array', 'items': {'type': 'string'}},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/certificate_provider'}
}

CHARGING_STRUCTURE_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'charging': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'fee_type': {'type': ["string", "null"]},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'fee_type'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/charging'}
}

COMMERCIAL_CHARGING_LEVEL_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'charging_level': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'collaboration': {'type': ['string', 'null']},
                'service_supplier': {'type': ['string', 'null']},
                'direct_peering': {'type': ['string', 'null']}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'collaboration', 'service_supplier', 'direct_peering'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/charging_level'}
}

COMMERCIAL_CONNECTIVITY_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'connectivity': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'commercial_r_and_e': {'type': ['string', 'null']},
                'commercial_general': {'type': ['string', 'null']},
                'commercial_collaboration': {'type': ['string', 'null']},
                'commercial_service_provider': {'type': ['string', 'null']},
                'university_spin_off': {'type': ['string', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'commercial_r_and_e',
                         'commercial_general', 'commercial_collaboration',
                         'commercial_service_provider', 'university_spin_off'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/connectivity'}
}

CONNECTED_PROPORTION_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'connectedproportion': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'user_category': {'type': ['string', 'null']},
                'coverage': {'type': ['string', 'null']},
                'number_connected': {'type': ['integer', 'null']},
                'market_share': {'type': ['number', 'null']},
                'users_served': {'type': ['integer', 'null']},

            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'user_category', 'coverage', 'number_connected',
                         'market_share', 'users_served'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/connectedproportion'}
}

CONNECTION_CARRIER_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'carrier': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'user_category': {'type': ['string', 'null']},
                'carry_mechanism': {'type': ['string', 'null']},

            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'user_category', 'carry_mechanism'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/carrier'}
}

CONNECTIVITY_GROWTH_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'growth': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'user_category': {'type': ['string', 'null']},
                'growth': {'type': ['integer', 'null']},

            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'user_category', 'growth'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/growth'}
}

CONNECTIVITY_LEVEL_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'level': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'user_category': {'type': ['string', 'null']},
                'typical_speed': {'type': ['integer', 'null']},
                'highest_speed': {'type': ['integer', 'null']},
                'highest_speed_proportion': {'type': ['number', 'null']},

            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'user_category', 'typical_speed',
                         'highest_speed', 'highest_speed_proportion'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/level'}
}

CONNECTIVITY_LOAD_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'level': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'user_category': {'type': ['string', 'null']},
                'average_load_from_institutions': {'type': ['integer', 'null']},
                'average_load_to_institutions': {'type': ['integer', 'null']},
                'peak_load_from_institutions': {'type': ['integer', 'null']},
                'peak_load_to_institutions': {'type': ['integer', 'null']},

            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'user_category', 'average_load_from_institutions',
                         'average_load_to_institutions', 'peak_load_from_institutions', 'peak_load_to_institutions'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/level'}
}

CORPORATE_STRATEGY_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'strategy': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'strategic_plan': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'strategic_plan'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/strategy'}
}

CRISIS_EXERCISES_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'crisis_exercises': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'exercise_descriptions': {'type': 'array', 'items': {'type': 'string'}}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/crisis_exercises'}
}

DARK_FIBRE_INSTALLED_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'dark_fibre_installed': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'installed': {'type': 'boolean'},
                'fibre_length_in_country': {'type': ['integer', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'installed', 'fibre_length_in_country'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/dark_fibre_installed'}
}

DARK_FIBRE_LEASE_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'dark_fibre': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'iru_or_lease': {'type': 'boolean'},
                'fibre_length_in_country': {'type': ['integer', 'null']},
                'fibre_length_outside_country': {'type': ['integer', 'null']},
                'iru_duration': {'type': ['number', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/dark_fibre'}
}

EC_PROJECTS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'ec_project': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'project': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'project'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/ec_project'}
}


EOSC_LISTINGS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'eosc_listings': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'service_names': {'type': 'array', 'items': {'type': 'string'}}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'service_names'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/eosc_listings'}
}

EXTERNAL_CONNECTIONS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'external_connection': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'link_name': {'type': 'string'},
                'capacity': {'type': ['number', 'null']},
                'from_organization': {'type': 'string'},
                'to_organization': {'type': 'string'},
                'interconnection_method': {'type': ['string', 'null']}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'link_name', 'capacity',
                         'from_organization', 'to_organization', 'interconnection_method'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/external_connection'}
}

FIBRE_LIGHT_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'fibre_light': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'light_description': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/fibre_light'}
}

FUNDING_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'funding': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'client_institutions': {'type': 'number'},
                'european_funding': {'type': 'number'},
                'gov_public_bodies': {'type': 'number'},
                'commercial': {'type': 'number'},
                'other': {'type': 'number'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'client_institutions',
                         'european_funding', 'gov_public_bodies', 'commercial', 'other'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/funding'}
}

INSTITUTION_URLS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'institution_urls': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'urls': {'type': 'array', 'items': {'type': 'string'}}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'urls'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/institution_urls'}
}

MONITORING_TOOLS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'monitoring_tools': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'tool_descriptions': {'type': 'array', 'items': {'type': 'string'}},
                'netflow_processing_description': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/monitoring_tools'}
}

NETWORK_AUTOMATION_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'alien_wave': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'network_automation': {'type': 'string'},
                'network_automation_specifics': {'type': 'array', 'items': {'type': 'string'}},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/alien_wave'}
}

NETWORK_FUNCTION_VIRTUALISATION_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'ops_automation': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'nfv': {'type': 'string'},
                'nfv_specifics': {'type': 'array', 'items': {'type': 'string'}},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/ops_automation'}
}

NETWORK_MAP_URLS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'network_map_url': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'urls': {'type': 'array', 'items': {'type': 'string'}},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/network_map_url'}
}

NON_R_AND_E_PEERS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'non_r_and_e_peers': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'nr_of_non_r_and_e_peers': {'type': 'integer'},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/non_r_and_e_peers'}
}

NREN_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'nren': {
            'type': 'object',
            'properties': {
                'id': {'type': 'integer'},
                'name': {'type': 'string'},
                'country': {'type': 'string'},
            },
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/nren'}
}

NREN_SERVICES_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'nren_services': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'product_name': {'type': 'string'},
                'additional_information': {'type': 'string'},
                'official_description': {'type': 'string'},
                'service_name': {'type': 'string'},
                'service_category': {'type': 'string'},
                'service_description': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'product_name', 'additional_information',
                         'official_description', 'service_name', 'service_category', 'service_description'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/nren_services'}
}

OPS_AUTOMATION_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'ops_automation': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'ops_automation': {'type': 'string'},
                'ops_automation_specifics': {'type': 'string'},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/ops_automation'}
}

ORGANIZATION_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'parent_organization': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'name': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'name'],
            'additionalProperties': False
        },
        'sub_organization': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'name': {'type': 'string'},
                'role': {'type': 'string'},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'name', 'role'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {
        'oneOf': [
            {'$ref': '#/definitions/parent_organization'},
            {'$ref': '#/definitions/sub_organization'}
        ]
    }
}

PASSIVE_MONITORING_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'pert_team': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'monitoring': {'type': 'boolean'},
                "method": {'type': ['string', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/pert_team'}
}

PERT_TEAM_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'pert_team': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'pert_team': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/pert_team'}
}

POLICY_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'policy': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'strategic_plan': {'type': 'string'},
                'environmental': {'type': 'string'},
                'equal_opportunity': {'type': 'string'},
                'connectivity': {'type': 'string'},
                'acceptable_use': {'type': 'string'},
                'privacy_notice': {'type': 'string'},
                'data_protection': {'type': 'string'},
                'gender_equality': {'type': 'string'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'strategic_plan', 'environmental', 'equal_opportunity',
                         'connectivity', 'acceptable_use', 'privacy_notice', 'data_protection'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/policy'}
}

REMOTE_CAMPUSES_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'connection': {
            'type': 'object',
            'properties': {
                'country': {'type': 'string'},
                'local_r_and_e_connection': {'type': ['boolean', 'null']},
            },
            'required': ['country', 'local_r_and_e_connection'],
            'additionalProperties': False
        },
        'remote_campuses': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'remote_campus_connectivity': {'type': 'boolean'},
                'connections': {'type': 'array', 'items': {'$ref': '#/definitions/connection'}}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'remote_campus_connectivity', 'connections'],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/remote_campuses'}
}

SECURITY_CONTROLS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'security_controls': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'security_control_descriptions': {'type': 'array', 'items': {'type': 'string'}}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/security_controls'}
}

SERVICE_MANAGEMENT_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'service_management': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'service_management_framework': {'type': ['boolean', 'null']},
                'service_level_targets': {'type': ['boolean', 'null']},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'service_management_framework', 'service_level_targets'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/service_management'}
}

SERVICE_USER_TYPES_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'services_user_types': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'user_category': {'type': 'string'},
                'service_category': {'type': 'string'}

            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'user_category', 'service_category'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/services_user_types'}
}

SIEM_VENDORS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'siem_vendors': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'vendor_names': {'type': 'array', 'items': {'type': 'string'}},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/siem_vendors'}
}

NREN_STAFF_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'staff': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'permanent_fte': {'type': 'number'},
                'subcontracted_fte': {'type': 'number'},
                'technical_fte': {'type': 'number'},
                'non_technical_fte': {'type': 'number'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED,
                         'permanent_fte', 'subcontracted_fte', 'technical_fte', 'non_technical_fte'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/staff'}
}

STANDARDS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'standards': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'audits': {'type': ['boolean', 'null']},
                'audit_specifics': {'type': 'string'},
                'business_continuity_plans': {'type': ['boolean', 'null']},
                'business_continuity_plans_specifics': {'type': 'string'},
                'crisis_management_procedure': {'type': ['boolean', 'null']}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/standards'}
}

TRAFFIC_VOLUME_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'traffic': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'to_customers': {'type': 'number'},
                'from_customers': {'type': 'number'},
                'to_external': {'type': 'number'},
                'from_external': {'type': 'number'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED, 'to_customers',
                         'from_customers', 'to_external', 'from_external'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/traffic'}
}

TRAFFIC_RATIO_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'traffic_ratio': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'r_and_e_percentage': {'type': 'number'},
                'commodity_percentage': {'type': 'number'}
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED,
                         'r_and_e_percentage', 'commodity_percentage'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/traffic_ratio'}
}

TRAFFIC_STATISTICS_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'traffic_statistics': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'traffic_statistics': {'type': 'boolean'},
                'urls': {'type': 'array', 'items': {'type': 'string'}},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/traffic_statistics'}
}

WEATHER_MAP_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'definitions': {
        'weather_map': {
            'type': 'object',
            'properties': {
                **NREN_YEAR_DATAPOINT,
                'weather_map': {'type': 'boolean'},
                'url': {'type': 'string'},
            },
            'required': [*NREN_YEAR_DATAPOINT_REQUIRED],
            'additionalProperties': False
        }
    },
    'type': 'array',
    'items': {'$ref': '#/definitions/weather_map'}
}
