import pytest

from compendium_v2.publishers.helpers import extract_urls


@pytest.mark.parametrize(
    "text, expected",
    [
        ("Check this: https://example.com and http://example.com\\", ["https://example.com", "http://example.com"]),
        ("No URL here", []),
        ("Incomplete URL: http://", []),
        ("Here is a www link: www.example.com", ["www.example.com"]),
        ("Another format: example.com", ["example.com"]),
        ("Mixed: https://example.com, http://site.org, www.site.net",
         ["https://example.com", "http://site.org", "www.site.net"]),
        ("With Parentheses: (https://example.com)", ["https://example.com"]),
        ("With Brackets: [https://example.com]", ["https://example.com"]),
        ("With Braces: {https://example.com}", ["https://example.com"]),
        ("With Semicolon: https://example.com;", ["https://example.com"]),
        ("With Dot at the end: https://example.com.", ["https://example.com"]),
        ("With Comma at the end: https://example.com,", ["https://example.com"]),
        ("With Exclamation at the end: https://example.com!", ["https://example.com"]),
        ("With Multiple special characters: https://example.com)!..d!;www.m.asd!)",
         ["https://example.com", "www.m.asd"]),
        ("URL with path: https://example.com/path/to/page", ["https://example.com/path/to/page"]),
        ("URL with path and query: https://example.com/path?query=value", ["https://example.com/path?query=value"]),
        ("URL with hash: https://example.com#section", ["https://example.com#section"]),
        ("URL with path, query and hash: https://example.com/path?query=value#section",
         ["https://example.com/path?query=value#section"]),
        ("URL with port: http://example.com:8080", ["http://example.com:8080"]),
        ("Multiple Complex: https://example.com/path, http://example.com:8080/page?query=value#section",
         ["https://example.com/path", "http://example.com:8080/page?query=value#section"]),
        ("URL with encoded characters: https://example.com/path%20to%20page", ["https://example.com/path%20to%20page"]),
        ("URL with encoded query: https://example.com/path?query=value%20with%20space",
         ["https://example.com/path?query=value%20with%20space"]),
        (
                "[URL with encoded hash: https://example.com/path#section%20two;]",
                ["https://example.com/path#section%20two"]
        ),
    ]
)
def test_extract_urls_from_a_text(text, expected):
    result = extract_urls(text)
    assert result == expected
